# Qt Extras
## General Scientific Python Qt GUI Utilities

A collection of Python Qt GUI builders and other functions I've found helpful as I develop
python mockups.

## Installation

`qtextras` lives in pypi too, so the easiest way to install it is through `pip`:

```bash
pip install qtextras
```

Note that a version of Qt must be installed for it to work, such as PyQt5/6 or Pyside2/6.
PySide6 will also be installed with `pip install qtextras[full]`

Alternatively, you can do so through downloading the repository:

```bash
git clone https://gitlab.com/s3a/qtextras
pip install -e ./qtextras # Or ./qtextras[full] as mentioned above
```

## Usage

Usage will vary depending on the requested capabilities. Check out the `examples`
folder for some usages